@@ -2,11 +2,11 @@ use 5.006;
 use strict;
 use warnings;
 package CPAN::Meta::Converter;
-our $VERSION = '2.112150'; # VERSION
+our $VERSION = '2.120351'; # VERSION
 
 
 use CPAN::Meta::Validator;
-use version 0.82 ();
+use version (); # Removed 0.82 constraint, EUMM installed CPAN::Meta
 use Parse::CPAN::Meta 1.4400 ();
 
 sub _dclone {
@@ -20,8 +20,8 @@ sub _dclone {
   local *UNIVERSAL::TO_JSON = sub { return "$_[0]" };
 
   my $backend = Parse::CPAN::Meta->json_backend();
-  return $backend->new->decode(
-    $backend->new->allow_blessed->convert_blessed->encode($ref)
+  return $backend->new->utf8->decode(
+    $backend->new->utf8->allow_blessed->convert_blessed->encode($ref)
   );
 }
 
@@ -316,7 +316,10 @@ sub _clean_version {
   return 0 if ! length $element;
   return 0 if ( $element eq 'undef' || $element eq '<undef>' );
 
-  if ( my $v = eval { version->new($element) } ) {
+  my $v = eval { version->new($element) };
+  # XXX check defined $v and not just $v because version objects leak memory
+  # in boolean context -- dagolden, 2012-02-03
+  if ( defined $v ) {
     return $v->is_qv ? $v->normal : $element;
   }
   else {
@@ -326,7 +329,7 @@ sub _clean_version {
 
 sub _version_map {
   my ($element) = @_;
-  return undef unless defined $element;
+  return unless defined $element;
   if ( ref $element eq 'HASH' ) {
     my $new_map = {};
     for my $k ( keys %$element ) {
@@ -429,9 +432,9 @@ sub _get_build_requires {
   my $test_h  = _extract_prereqs($_[2]->{prereqs}, qw(test  requires)) || {};
   my $build_h = _extract_prereqs($_[2]->{prereqs}, qw(build requires)) || {};
 
-  require Version::Requirements;
-  my $test_req  = Version::Requirements->from_string_hash($test_h);
-  my $build_req = Version::Requirements->from_string_hash($build_h);
+  require CPAN::Meta::Requirements;
+  my $test_req  = CPAN::Meta::Requirements->from_string_hash($test_h);
+  my $build_req = CPAN::Meta::Requirements->from_string_hash($build_h);
 
   $test_req->add_requirements($build_req)->as_string_hash;
 }
@@ -444,7 +447,7 @@ sub _extract_prereqs {
 
 sub _downgrade_optional_features {
   my (undef, undef, $meta) = @_;
-  return undef unless exists $meta->{optional_features};
+  return unless exists $meta->{optional_features};
   my $origin = $meta->{optional_features};
   my $features = {};
   for my $name ( keys %$origin ) {
@@ -465,7 +468,7 @@ sub _downgrade_optional_features {
 
 sub _upgrade_optional_features {
   my (undef, undef, $meta) = @_;
-  return undef unless exists $meta->{optional_features};
+  return unless exists $meta->{optional_features};
   my $origin = $meta->{optional_features};
   my $features = {};
   for my $name ( keys %$origin ) {
@@ -561,7 +564,7 @@ my $resource2_upgrade = {
     return unless $item;
     if ( $item =~ m{^mailto:(.*)$} ) { return { mailto => $1 } }
     elsif( _is_urlish($item) ) { return { web => $item } }
-    else { return undef }
+    else { return }
   },
   repository => sub { return _is_urlish($_[0]) ? { url => $_[0] } : undef },
   ':custom'  => \&_prefix_custom,
@@ -569,7 +572,7 @@ my $resource2_upgrade = {
 
 sub _upgrade_resources_2 {
   my (undef, undef, $meta, $version) = @_;
-  return undef unless exists $meta->{resources};
+  return unless exists $meta->{resources};
   return _convert($meta->{resources}, $resource2_upgrade);
 }
 
@@ -607,7 +610,7 @@ my $resources2_cleanup = {
 
 sub _cleanup_resources_2 {
   my ($resources, $key, $meta, $to_version) = @_;
-  return undef unless $resources && ref $resources eq 'HASH';
+  return unless $resources && ref $resources eq 'HASH';
   return _convert($resources, $resources2_cleanup, $to_version);
 }
 
@@ -621,7 +624,7 @@ my $resource1_spec = {
 
 sub _resources_1_3 {
   my (undef, undef, $meta, $version) = @_;
-  return undef unless exists $meta->{resources};
+  return unless exists $meta->{resources};
   return _convert($meta->{resources}, $resource1_spec);
 }
 
@@ -634,7 +637,7 @@ sub _resources_1_2 {
     $resources->{license} = $meta->license_url
       if _is_urlish($meta->{license_url});
   }
-  return undef unless keys %$resources;
+  return unless keys %$resources;
   return _convert($resources, $resource1_spec);
 }
 
@@ -648,7 +651,7 @@ my $resource_downgrade_spec = {
 
 sub _downgrade_resources {
   my (undef, undef, $meta, $version) = @_;
-  return undef unless exists $meta->{resources};
+  return unless exists $meta->{resources};
   return _convert($meta->{resources}, $resource_downgrade_spec);
 }
 
@@ -1260,7 +1263,7 @@ CPAN::Meta::Converter - Convert CPAN distribution metadata structures
 
 =head1 VERSION
 
-version 2.112150
+version 2.120351
 
 =head1 SYNOPSIS
 
